import x from "x;/";
import y from "y;";
const obj = (y, x);
